@@ -3,7 +3,7 @@ use warnings;
 
 package Dancer2::Plugin::Auth::HTTP::Basic::DWIW;
 # ABSTRACT: HTTP Basic authentication plugin for Dancer2 that does what I want.
-$Dancer2::Plugin::Auth::HTTP::Basic::DWIW::VERSION = '0.04';
+$Dancer2::Plugin::Auth::HTTP::Basic::DWIW::VERSION = '0.05';
 use MIME::Base64;
 use Dancer2::Plugin;
 
@@ -23,7 +23,7 @@ register http_basic_auth => sub {
 
             $auth_method ne 'Basic' || $auth_string || die \400;
 
-            my ($username, $password) = split(':', decode_base64($auth_string));
+            my ($username, $password) = split(':', decode_base64($auth_string), 2);
 
             $username || $password || die \401;
 
@@ -48,7 +48,7 @@ register http_basic_auth => sub {
 
             $dsl->header('WWW-Authenticate' => 'Basic realm="' . $realm . '"');
             $dsl->status($error_code);
-            return $error_code;
+            return;
         }
     };
 };
@@ -59,7 +59,7 @@ register http_basic_auth_login => sub {
 
     my @auth_header = split(' ', $dsl->app->request->header('Authorization'));
     my $auth_string = $auth_header[1];
-    my @auth_parts  = split(':', decode_base64($auth_string));
+    my @auth_parts  = split(':', decode_base64($auth_string), 2);
 
     return @auth_parts;
 },
@@ -87,7 +87,7 @@ Dancer2::Plugin::Auth::HTTP::Basic::DWIW - HTTP Basic authentication plugin for
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -156,7 +156,7 @@ Moritz Grosch (LittleFox) <littlefox@fsfe.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Moritz Grosch (LittleFox).
+This software is copyright (c) 2017 by Moritz Grosch (LittleFox).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
